@@ -187,7 +187,9 @@ class VimaniaManager:
         if is_modifiable:
             vim.current.buffer[:] = new_text
         else:
-            _log.warning(f"Current buffer {vim.current.buffer.name}:{vim.current.buffer.number} = {is_modifiable=}")
+            _log.warning(
+                f"Current buffer {vim.current.buffer.name}:{vim.current.buffer.number} = {is_modifiable=}"
+            )
 
     @staticmethod
     @err_to_scratch_buffer
